package com.link.core.converter.util;

import java.text.MessageFormat;
import java.util.Collection;
import java.util.Date;
import java.util.Map;
import java.util.ResourceBundle;

public class Assert {
   private static final ResourceBundle res = ResourceBundleUtil.getBundle(ExceptionUtil.class, "R");

   public static void assertArgumentNotNull(Object argument, String argumentName) throws IllegalArgumentException {
      if (argument == null) {
         throw ExceptionUtil.nullArgument(argumentName);
      }
   }

   public static void assertAttributeNotNull(Object attribute, String attributeName) throws IllegalStateException {
      if (attribute == null) {
         throw ExceptionUtil.nullAttribute(attributeName);
      }
   }

   public static void assertStringNotTooLong(String argument, int maxLength, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.length() > maxLength) {
         throw ExceptionUtil.stringTooLong(argumentName, (long)maxLength);
      }
   }

   public static void unsupportedOperation(String methodName) throws UnsupportedOperationException {
      throw ExceptionUtil.neverCallMe(methodName);
   }

   public static void isTrue(boolean expression, String message) throws IllegalArgumentException {
      if (!expression) {
         throw new IllegalArgumentException(message);
      }
   }

   public static void state(boolean expression, String message) throws IllegalStateException {
      if (!expression) {
         throw new IllegalStateException(message);
      }
   }

   public static void notNull(Object argument) throws IllegalArgumentException {
      if (argument == null) {
         throw new IllegalArgumentException(res.getString("notNull"));
      }
   }

   public static void notNull(Object argument, String argumentName) throws IllegalArgumentException {
      if (argument == null) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notNullArg"), argumentName));
      }
   }

   public static void hasLength(String argument) throws IllegalArgumentException {
      if (StringUtil.isNullOrEmpty(argument)) {
         throw new IllegalArgumentException(res.getString("hasLength"));
      }
   }

   public static void hasLength(String argument, String argumentName) throws IllegalArgumentException {
      if (StringUtil.isNullOrEmpty(argument)) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("hasLengthArg"), argumentName));
      }
   }

   public static void hasText(String argument) throws IllegalArgumentException {
      if (StringUtil.isNullOrBlank(argument)) {
         throw new IllegalArgumentException(res.getString("hasText"));
      }
   }

   public static void hasText(String argument, String argumentName) throws IllegalArgumentException {
      if (StringUtil.isNullOrBlank(argument)) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("hasTextArg"), argumentName));
      }
   }

   public static void notTooLong(String argument, int maxLength) throws IllegalArgumentException {
      if (argument != null && argument.length() > maxLength) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooLong"), maxLength, argument));
      }
   }

   public static void notTooLong(String argument, int maxLength, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.length() > maxLength) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooLongArg"), argumentName, maxLength, argument));
      }
   }

   public static void isAssignable(Class<?> superType, Class<?> subType) throws IllegalArgumentException {
      isAssignable(superType, subType, "");
   }

   public static void isAssignable(Class<?> superType, Class<?> subType, String message) throws IllegalArgumentException {
      notNull(superType, "superType");
      if (subType == null || !superType.isAssignableFrom(subType)) {
         throw new IllegalArgumentException(message + MessageFormat.format(res.getString("isAssignable"), subType, superType));
      }
   }

   public static void isInstanceOf(Class<?> clazz, Object argument) throws IllegalArgumentException {
      notNull(clazz, "clazz");
      if (!clazz.isInstance(argument)) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("isInstanceOf"), clazz, argument));
      }
   }

   public static void isInstanceOf(Class<?> clazz, Object argument, String argumentName) throws IllegalArgumentException {
      notNull(clazz, "clazz");
      if (!clazz.isInstance(argument)) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("isInstanceOfArg"), argumentName, clazz, argument));
      }
   }

   public static void notEmpty(Object[] argument) throws IllegalArgumentException {
      if (argument == null || argument.length == 0) {
         throw new IllegalArgumentException(res.getString("notEmpty"));
      }
   }

   public static void notEmpty(Object[] argument, String argumentName) throws IllegalArgumentException {
      if (argument == null || argument.length == 0) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notEmptyArg"), argumentName));
      }
   }

   public static void notEmpty(Collection<?> argument) throws IllegalArgumentException {
      if (argument == null || argument.isEmpty()) {
         throw new IllegalArgumentException(res.getString("notEmpty"));
      }
   }

   public static void notEmpty(Collection<?> argument, String argumentName) throws IllegalArgumentException {
      if (argument == null || argument.isEmpty()) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notEmptyArg"), argumentName));
      }
   }

   public static void notEmpty(Map<?, ?> argument) throws IllegalArgumentException {
      if (argument == null || argument.isEmpty()) {
         throw new IllegalArgumentException(res.getString("notEmpty"));
      }
   }

   public static void notEmpty(Map<?, ?> argument, String argumentName) throws IllegalArgumentException {
      if (argument == null || argument.isEmpty()) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notEmptyArg"), argumentName));
      }
   }

   public static void notNullElements(Object[] argument) throws IllegalArgumentException {
      if (argument != null) {
         Object[] var1 = argument;
         int var2 = argument.length;

         for(int var3 = 0; var3 < var2; ++var3) {
            Object item = var1[var3];
            if (item == null) {
               throw new IllegalArgumentException(res.getString("notNullElements"));
            }
         }
      }

   }

   public static void notNullElements(Object[] argument, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         Object[] var2 = argument;
         int var3 = argument.length;

         for(int var4 = 0; var4 < var3; ++var4) {
            Object item = var2[var4];
            if (item == null) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("notNullElementsArg"), argumentName));
            }
         }
      }

   }

   public static void notNullElements(Collection argument) throws IllegalArgumentException {
      if (argument != null && argument.contains((Object)null)) {
         throw new IllegalArgumentException(res.getString("notNullElements"));
      }
   }

   public static void notNullElements(Collection argument, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.contains((Object)null)) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notNullElementsArg"), argumentName));
      }
   }

   public static void notTooMany(Object[] argument, int maxSize) throws IllegalArgumentException {
      if (argument != null && argument.length > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyArray"), argument.length, maxSize));
      }
   }

   public static void notTooMany(Object[] argument, int maxSize, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.length > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyArrayArg"), argumentName, argument.length, maxSize));
      }
   }

   public static void notTooMany(Collection argument, int maxSize) throws IllegalArgumentException {
      if (argument != null && argument.size() > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyCollection"), argument.size(), maxSize));
      }
   }

   public static void notTooMany(Collection argument, int maxSize, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.size() > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyCollectionArg"), argumentName, argument.size(), maxSize));
      }
   }

   public static void notTooMany(Map argument, int maxSize) throws IllegalArgumentException {
      if (argument != null && argument.size() > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyMap"), argument.size(), maxSize));
      }
   }

   public static void notTooMany(Map argument, int maxSize, String argumentName) throws IllegalArgumentException {
      if (argument != null && argument.size() > maxSize) {
         throw new IllegalArgumentException(MessageFormat.format(res.getString("notTooManyMapArg"), argumentName, argument.size(), maxSize));
      }
   }

   public static void greater(Number argument, byte low, boolean equals) throws IllegalArgumentException {
      greater(argument, (double)low, equals);
   }

   public static void greater(Number argument, byte low, boolean equals, String argumentName) throws IllegalArgumentException {
      greater(argument, (double)low, equals, argumentName);
   }

   public static void greater(Number argument, int low, boolean equals) throws IllegalArgumentException {
      greater(argument, (double)low, equals);
   }

   public static void greater(Number argument, int low, boolean equals, String argumentName) throws IllegalArgumentException {
      greater(argument, (double)low, equals, argumentName);
   }

   public static void greater(Number argument, long low, boolean equals) throws IllegalArgumentException {
      greater(argument, (double)low, equals);
   }

   public static void greater(Number argument, long low, boolean equals, String argumentName) throws IllegalArgumentException {
      greater(argument, (double)low, equals, argumentName);
   }

   public static void greater(Number argument, float low, boolean equals) throws IllegalArgumentException {
      greater(argument, (double)low, equals);
   }

   public static void greater(Number argument, float low, boolean equals, String argumentName) throws IllegalArgumentException {
      greater(argument, (double)low, equals, argumentName);
   }

   public static void greater(Number argument, double low, boolean equals) throws IllegalArgumentException {
      if (argument != null) {
         if (equals) {
            if (argument.doubleValue() < low) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("greaterOrEquals"), low, argument));
            }
         } else if (argument.doubleValue() <= low) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("greater"), low, argument));
         }
      }

   }

   public static void greater(Number argument, double low, boolean equals, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         if (equals) {
            if (argument.doubleValue() < low) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("greaterOrEqualsArg"), argumentName, low, argument));
            }
         } else if (argument.doubleValue() <= low) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("greaterArg"), argumentName, low, argument));
         }
      }

   }

   public static void less(Number argument, byte high, boolean equals) throws IllegalArgumentException {
      less(argument, (double)high, equals);
   }

   public static void less(Number argument, byte high, boolean equals, String argumentName) throws IllegalArgumentException {
      less(argument, (double)high, equals, argumentName);
   }

   public static void less(Number argument, int high, boolean equals) throws IllegalArgumentException {
      less(argument, (double)high, equals);
   }

   public static void less(Number argument, int high, boolean equals, String argumentName) throws IllegalArgumentException {
      less(argument, (double)high, equals, argumentName);
   }

   public static void less(Number argument, long high, boolean equals) throws IllegalArgumentException {
      less(argument, (double)high, equals);
   }

   public static void less(Number argument, long high, boolean equals, String argumentName) throws IllegalArgumentException {
      less(argument, (double)high, equals, argumentName);
   }

   public static void less(Number argument, float high, boolean equals) throws IllegalArgumentException {
      less(argument, (double)high, equals);
   }

   public static void less(Number argument, float high, boolean equals, String argumentName) throws IllegalArgumentException {
      less(argument, (double)high, equals, argumentName);
   }

   public static void less(Number argument, double high, boolean equals) throws IllegalArgumentException {
      if (argument != null) {
         if (equals) {
            if (argument.doubleValue() > high) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("lessOrEquals"), high, argument));
            }
         } else if (argument.doubleValue() >= high) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("less"), high, argument));
         }
      }

   }

   public static void less(Number argument, double high, boolean equals, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         if (equals) {
            if (argument.doubleValue() > high) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("lessOrEqualsArg"), argumentName, high, argument));
            }
         } else if (argument.doubleValue() >= high) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("lessArg"), argumentName, high, argument));
         }
      }

   }

   public static void between(Number argument, byte low, boolean equalsLow, byte high, boolean equalsHigh) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh);
   }

   public static void between(Number argument, byte low, boolean equalsLow, byte high, boolean equalsHigh, String argumentName) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh, argumentName);
   }

   public static void between(Number argument, int low, boolean equalsLow, int high, boolean equalsHigh) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh);
   }

   public static void between(Number argument, int low, boolean equalsLow, int high, boolean equalsHigh, String argumentName) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh, argumentName);
   }

   public static void between(Number argument, long low, boolean equalsLow, long high, boolean equalsHigh) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh);
   }

   public static void between(Number argument, long low, boolean equalsLow, long high, boolean equalsHigh, String argumentName) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh, argumentName);
   }

   public static void between(Number argument, float low, boolean equalsLow, float high, boolean equalsHigh) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh);
   }

   public static void between(Number argument, float low, boolean equalsLow, float high, boolean equalsHigh, String argumentName) throws IllegalArgumentException {
      between(argument, (double)low, equalsLow, (double)high, equalsHigh, argumentName);
   }

   public static void between(Number argument, double low, boolean equalsLow, double high, boolean equalsHigh) throws IllegalArgumentException {
      try {
         greater(argument, low, equalsLow);
         less(argument, high, equalsHigh);
      } catch (IllegalArgumentException var9) {
         StringBuilder key = new StringBuilder();
         key.append("between");
         if (equalsLow) {
            key.append("Close");
         } else {
            key.append("Open");
         }

         if (equalsHigh) {
            key.append("Close");
         } else {
            key.append("Open");
         }

         throw new IllegalArgumentException(MessageFormat.format(res.getString(key.toString()), low, high, argument));
      }
   }

   public static void between(Number argument, double low, boolean equalsLow, double high, boolean equalsHigh, String argumentName) throws IllegalArgumentException {
      try {
         greater(argument, low, equalsLow);
         less(argument, high, equalsHigh);
      } catch (IllegalArgumentException var10) {
         StringBuilder key = new StringBuilder();
         key.append("between");
         if (equalsLow) {
            key.append("Close");
         } else {
            key.append("Open");
         }

         if (equalsHigh) {
            key.append("Close");
         } else {
            key.append("Open");
         }

         key.append("Arg");
         throw new IllegalArgumentException(MessageFormat.format(res.getString(key.toString()), argumentName, low, high, argument));
      }
   }

   public static void after(Date argument, Date base, boolean allowEquals) throws IllegalArgumentException {
      if (argument != null) {
         Date ripeBase = base == null ? new Date() : base;

         try {
            greater(argument.getTime(), ripeBase.getTime(), allowEquals);
         } catch (IllegalArgumentException var5) {
            if (allowEquals) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("afterOrEquals"), ripeBase, argument));
            } else {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("after"), ripeBase, argument));
            }
         }
      }
   }

   public static void after(Date argument, Date base, boolean allowEquals, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         Date ripeBase = base == null ? new Date() : base;

         try {
            greater(argument.getTime(), ripeBase.getTime(), allowEquals);
         } catch (IllegalArgumentException var6) {
            if (allowEquals) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("afterOrEqualsArg"), argumentName, ripeBase, argument));
            } else {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("afterArg"), argumentName, ripeBase, argument));
            }
         }
      }
   }

   public static void before(Date argument, Date base, boolean allowEquals) throws IllegalArgumentException {
      if (argument != null) {
         Date ripeBase = base == null ? new Date() : base;

         try {
            less(argument.getTime(), ripeBase.getTime(), allowEquals);
         } catch (IllegalArgumentException var5) {
            if (allowEquals) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("beforeOrEquals"), ripeBase, argument));
            } else {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("before"), ripeBase, argument));
            }
         }
      }
   }

   public static void before(Date argument, Date base, boolean allowEquals, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         Date ripeBase = base == null ? new Date() : base;

         try {
            less(argument.getTime(), ripeBase.getTime(), allowEquals);
         } catch (IllegalArgumentException var6) {
            if (allowEquals) {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("beforeOrEqualsArg"), argumentName, ripeBase, argument));
            } else {
               throw new IllegalArgumentException(MessageFormat.format(res.getString("beforeArg"), argumentName, ripeBase, argument));
            }
         }
      }
   }

   public static void isFuture(Date argument) throws IllegalArgumentException {
      if (argument != null) {
         try {
            greater(argument.getTime(), System.currentTimeMillis(), false);
         } catch (IllegalArgumentException var2) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("isFuture"), argument));
         }
      }
   }

   public static void isFuture(Date argument, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         try {
            greater(argument.getTime(), System.currentTimeMillis(), false);
         } catch (IllegalArgumentException var3) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("isFutureArg"), argumentName, argument));
         }
      }
   }

   public static void isHistory(Date argument) throws IllegalArgumentException {
      if (argument != null) {
         try {
            less(argument.getTime(), System.currentTimeMillis(), false);
         } catch (IllegalArgumentException var2) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("isHistory"), argument));
         }
      }
   }

   public static void isHistory(Date argument, String argumentName) throws IllegalArgumentException {
      if (argument != null) {
         try {
            less(argument.getTime(), System.currentTimeMillis(), false);
         } catch (IllegalArgumentException var3) {
            throw new IllegalArgumentException(MessageFormat.format(res.getString("isHistoryArg"), argumentName, argument));
         }
      }
   }
}
